==> pubnub-3.0.0-rc.1.tar.gz: lib/src/subscribe/manager.dart <==
import 'dart:async';

import 'package:pubnub/core.dart';

import 'subscribe_loop/subscribe_loop_state.dart';
import 'subscribe_loop/subscribe_loop.dart';
import 'subscription.dart';
import 'envelope.dart';

/// @nodoc
class Manager {
  final Keyset _keyset;

  final Set<Subscription> _subscriptions = {};

  SubscribeLoop _loop;

  Stream<Envelope> get envelopes => _loop.envelopes;

  Manager(Core core, this._keyset) {
    _loop = SubscribeLoop(core, SubscribeLoopState(_keyset));
  }

  void _updateLoop() {
    var channels = _subscriptions.fold<Set<String>>(
        <String>{},
        (s, sub) => s
          ..addAll(<String>{
            ...sub.channels,
            if (sub.withPresence == true) ...sub.presenceChannels
          }));
    var channelGroups = _subscriptions.fold<Set<String>>(
        <String>{},
        (s, sub) => s
          ..addAll(<String>{
            ...sub.channelGroups,
            if (sub.withPresence == true) ...sub.presenceChannelGroups
          }));

    _loop.update((state) =>
        state.clone(channels: channels, channelGroups: channelGroups));
  }

  Subscription createSubscription(
      {Set<String> channels, Set<String> channelGroups, bool withPresence}) {
    var subscription =
        Subscription(this, channels, channelGroups, withPresence);

    _subscriptions.add(subscription);

    _updateLoop();

    return subscription;
  }

  Future<void> unsubscribeAll() async {
    for (var subscription in _subscriptions) {
      await subscription.cancel();
    }
  }
}

==> pubnub-3.2.0.tar.gz: lib/src/subscribe/manager.dart <==
import 'dart:async';

import 'package:pubnub/core.dart';

import 'subscribe_loop/subscribe_loop_state.dart';
import 'subscribe_loop/subscribe_loop.dart';
import 'subscription.dart';
import 'envelope.dart';

/// @nodoc
class Manager {
  final Keyset keyset;

  final Set<Subscription> subscriptions = {};

  SubscribeLoop _loop;

  Stream<Envelope> get envelopes => _loop.envelopes;

  Manager(Core core, this.keyset) {
    _loop = SubscribeLoop(core, SubscribeLoopState(keyset));
  }

  void _updateLoop() {
    var channels = subscriptions.fold<Set<String>>(
        <String>{},
        (s, sub) => s
          ..addAll(<String>{
            ...sub.channels,
            if (sub.withPresence == true) ...sub.presenceChannels
          }));
    var channelGroups = subscriptions.fold<Set<String>>(
        <String>{},
        (s, sub) => s
          ..addAll(<String>{
            ...sub.channelGroups,
            if (sub.withPresence == true) ...sub.presenceChannelGroups
          }));

    _loop.update((state) =>
        state.clone(channels: channels, channelGroups: channelGroups));
  }

  Subscription createSubscription(
      {Set<String> channels,
      Set<String> channelGroups,
      bool withPresence = false}) {
    var subscription =
        Subscription(this, channels, channelGroups, withPresence);

    subscriptions.add(subscription);

    _updateLoop();

    return subscription;
  }

  Future<void> unsubscribeAll() async {
    for (var subscription in subscriptions) {
      await subscription.cancel();
    }
  }
}
